==> paraview-2.4.2.tbz: lib/paraview-2.4/ParaViewLibraryDepends.cmake <==
SET(SPCTH_LIB_DEPENDS "")
SET(vtkClientServer_LIB_DEPENDS "vtkCommon;")
SET(vtkCommonTCL_LIB_DEPENDS "vtkCommon;vtkRendering;/usr/local/lib/paraview-2.4-build/Utilities/TclTk/tcl8.4.5/unix/libtcl8.4.a;/usr/local/lib/paraview-2.4-build/Utilities/TclTk/tk8.4.5/unix/libtk8.4.a;-lm;-lXt;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;")
SET(vtkCommon_LIB_DEPENDS "vtksys;-lpthread;-lm;")
SET(vtkFiltering_LIB_DEPENDS "vtkCommon;")
SET(vtkImaging_LIB_DEPENDS "vtkFiltering;")
SET(vtkGraphics_LIB_DEPENDS "vtkFiltering;")
SET(vtkGenericFiltering_LIB_DEPENDS "vtkFiltering;vtkGraphics;")
SET(vtkIO_LIB_DEPENDS "vtkFiltering;vtkDICOMParser;vtkpng;vtkzlib;vtkjpeg;vtktiff;vtkexpat;vtksys;vtkMPEG2Encode;")
SET(vtkRendering_LIB_DEPENDS "vtkGraphics;vtkImaging;vtkIO;vtkftgl;vtkfreetype;/usr/X11R6/lib/libGL.so;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;")
SET(vtkVolumeRendering_LIB_DEPENDS "vtkRendering;vtkIO;")
SET(vtkHybrid_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtkWidgets_LIB_DEPENDS "vtkRendering;vtkHybrid;")
SET(vtkParallel_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtksys_LIB_DEPENDS "")
SET(vtkzlib_LIB_DEPENDS "")
SET(vtkjpeg_LIB_DEPENDS "")
SET(vtkpng_LIB_DEPENDS "vtkzlib;")
SET(vtktiff_LIB_DEPENDS "vtkzlib;vtkjpeg;")
SET(vtkexpat_LIB_DEPENDS "")
SET(vtkfreetype_LIB_DEPENDS "")
SET(vtkDICOMParser_LIB_DEPENDS "")
SET(vtkMPEG2Encode_LIB_DEPENDS "")
SET(vtkNetCDF_LIB_DEPENDS "")
SET(vtkexoIIc_LIB_DEPENDS "vtkNetCDF;")
SET(vtkftgl_LIB_DEPENDS "/usr/X11R6/lib/libGL.so;vtkfreetype;")
SET(Xdmf_LIB_DEPENDS "/usr/local/lib/libhdf5.so;vtkexpat;")
SET(vtkXdmf_LIB_DEPENDS "vtkIO;Xdmf;vtkRendering;vtkParallel;")
SET(KWCommon_LIB_DEPENDS "vtkFiltering;vtkGenericFiltering;vtkGraphics;vtkIO;vtkImaging;vtkRendering;vtksys;")
SET(vtkCommonCS_LIB_DEPENDS "vtkClientServer;vtkCommon;")
SET(vtkFilteringCS_LIB_DEPENDS "vtkClientServer;vtkFiltering;vtkCommonCS;")
SET(vtkGenericFilteringCS_LIB_DEPENDS "vtkClientServer;vtkGenericFiltering;vtkFilteringCS;")
SET(vtkImagingCS_LIB_DEPENDS "vtkClientServer;vtkImaging;vtkFilteringCS;")
SET(vtkGraphicsCS_LIB_DEPENDS "vtkClientServer;vtkGraphics;vtkFilteringCS;")
SET(vtkIOCS_LIB_DEPENDS "vtkClientServer;vtkIO;vtkFilteringCS;")
SET(vtkRenderingCS_LIB_DEPENDS "vtkClientServer;vtkRendering;vtkGenericFilteringCS;vtkGraphicsCS;vtkImagingCS;vtkIOCS;")
SET(vtkHybridCS_LIB_DEPENDS "vtkClientServer;vtkHybrid;vtkRenderingCS;")
SET(vtkParallelCS_LIB_DEPENDS "vtkClientServer;vtkParallel;vtkRenderingCS;")
SET(vtkVolumeRenderingCS_LIB_DEPENDS "vtkClientServer;vtkVolumeRendering;vtkRenderingCS;")
SET(vtkWidgetsCS_LIB_DEPENDS "vtkClientServer;vtkWidgets;vtkRenderingCS;")
SET(vtkXdmfCS_LIB_DEPENDS "vtkClientServer;vtkXdmf;vtkRenderingCS;")
SET(vtkPVServerCommon_LIB_DEPENDS "vtkHybridCS;vtkParallelCS;KWCommon;vtksys;/usr/local/lib/libhdf5.so;vtkClientServer;")
SET(vtkPVServerCommonCS_LIB_DEPENDS "vtkClientServer;vtkPVServerCommon;vtkParallelCS;vtkHybridCS;vtkRenderingCS;")
SET(vtkPVServerCommonTCL_LIB_DEPENDS "vtkPVServerCommon;vtkCommonTCL;")
SET(vtkPVFilters_LIB_DEPENDS "vtkPVServerCommon;vtkPVServerCommonCS;vtkXdmfCS;vtkHybridCS;vtkParallelCS;vtkVolumeRenderingCS;vtkWidgetsCS;KWCommon;vtksys;/usr/local/lib/libhdf5.so;SPCTH;vtkClientServer;")
SET(vtkPVFiltersCS_LIB_DEPENDS "vtkClientServer;vtkPVFilters;vtkParallelCS;vtkHybridCS;vtkRenderingCS;vtkVolumeRenderingCS;")
SET(vtkPVServerManager_LIB_DEPENDS "vtkPVFiltersCS;vtkClientServer;KWCommon;")
SET(vtkPVServerManagerTCL_LIB_DEPENDS "vtkPVServerCommonTCL;vtkPVServerManager;vtkCommonTCL;")
SET(KWWidgets_LIB_DEPENDS "vtkCommonTCL;vtkRendering;vtkVolumeRendering;vtkHybrid;vtkWidgets;vtkParallel;vtkpng;vtksys;")
SET(vtkKWParaView_LIB_DEPENDS "KWCommon;KWWidgets;vtkPVServerManagerTCL;vtkPVServerCommonTCL;vtkPVFilters;vtkXdmfCS;")
SET(vtkKWParaViewCS_LIB_DEPENDS "vtkClientServer;vtkKWParaView;vtkPVFiltersCS;vtkPVServerCommonCS;")
SET(KWSimpleWindowWithImageWidgetExampleLib_LIB_DEPENDS "")

==> paraview-2.4.4.tbz: lib/paraview-2.4/ParaViewLibraryDepends.cmake <==
SET(SPCTH_LIB_DEPENDS "")
SET(vtkClientServer_LIB_DEPENDS "vtkCommon;")
SET(vtkCommonTCL_LIB_DEPENDS "vtkCommon;vtkRendering;/usr/local/lib/paraview-2.4-build/Utilities/TclTk/tcl8.4.5/unix/libtcl8.4.a;/usr/local/lib/paraview-2.4-build/Utilities/TclTk/tk8.4.5/unix/libtk8.4.a;-lm;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;")
SET(vtkCommon_LIB_DEPENDS "vtksys;-lpthread;-lm;")
SET(vtkFiltering_LIB_DEPENDS "vtkCommon;")
SET(vtkImaging_LIB_DEPENDS "vtkFiltering;")
SET(vtkGraphics_LIB_DEPENDS "vtkFiltering;")
SET(vtkGenericFiltering_LIB_DEPENDS "vtkFiltering;vtkGraphics;")
SET(vtkIO_LIB_DEPENDS "vtkFiltering;vtkDICOMParser;/usr/local/lib/libpng.so;/usr/lib/libz.so;/usr/lib/libz.so;/usr/local/lib/libjpeg.so;/usr/local/lib/libtiff.so;/usr/local/lib/libexpat.so;vtksys;vtkMPEG2Encode;")
SET(vtkRendering_LIB_DEPENDS "vtkGraphics;vtkImaging;vtkIO;vtkftgl;/usr/local/lib/libfreetype.so;/usr/X11R6/lib/libGL.so;-lXt;-lSM;-lICE;-lSM;-lICE;-lSM;-lICE;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;/usr/X11R6/lib/libX11.so;/usr/X11R6/lib/libXext.so;")
SET(vtkVolumeRendering_LIB_DEPENDS "vtkRendering;vtkIO;")
SET(vtkHybrid_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtkWidgets_LIB_DEPENDS "vtkRendering;vtkHybrid;")
SET(vtkParallel_LIB_DEPENDS "vtkRendering;vtkIO;vtkexoIIc;")
SET(vtksys_LIB_DEPENDS "")
SET(vtkDICOMParser_LIB_DEPENDS "")
SET(vtkMPEG2Encode_LIB_DEPENDS "")
SET(vtkNetCDF_LIB_DEPENDS "")
SET(vtkexoIIc_LIB_DEPENDS "vtkNetCDF;")
SET(vtkftgl_LIB_DEPENDS "/usr/X11R6/lib/libGL.so;/usr/local/lib/libfreetype.so;")
SET(Xdmf_LIB_DEPENDS "/usr/local/lib/libhdf5.so;/usr/local/lib/libexpat.so;")
SET(vtkXdmf_LIB_DEPENDS "vtkIO;Xdmf;vtkRendering;vtkParallel;")
SET(KWCommon_LIB_DEPENDS "vtkFiltering;vtkGenericFiltering;vtkGraphics;vtkIO;vtkImaging;vtkRendering;vtksys;")
SET(vtkCommonCS_LIB_DEPENDS "vtkClientServer;vtkCommon;")
SET(vtkFilteringCS_LIB_DEPENDS "vtkClientServer;vtkFiltering;vtkCommonCS;")
SET(vtkGenericFilteringCS_LIB_DEPENDS "vtkClientServer;vtkGenericFiltering;vtkFilteringCS;")
SET(vtkImagingCS_LIB_DEPENDS "vtkClientServer;vtkImaging;vtkFilteringCS;")
SET(vtkGraphicsCS_LIB_DEPENDS "vtkClientServer;vtkGraphics;vtkFilteringCS;")
SET(vtkIOCS_LIB_DEPENDS "vtkClientServer;vtkIO;vtkFilteringCS;")
SET(vtkRenderingCS_LIB_DEPENDS "vtkClientServer;vtkRendering;vtkGenericFilteringCS;vtkGraphicsCS;vtkImagingCS;vtkIOCS;")
SET(vtkHybridCS_LIB_DEPENDS "vtkClientServer;vtkHybrid;vtkRenderingCS;")
SET(vtkParallelCS_LIB_DEPENDS "vtkClientServer;vtkParallel;vtkRenderingCS;")
SET(vtkVolumeRenderingCS_LIB_DEPENDS "vtkClientServer;vtkVolumeRendering;vtkRenderingCS;")
SET(vtkWidgetsCS_LIB_DEPENDS "vtkClientServer;vtkWidgets;vtkRenderingCS;")
SET(vtkXdmfCS_LIB_DEPENDS "vtkClientServer;vtkXdmf;vtkRenderingCS;")
SET(vtkPVServerCommon_LIB_DEPENDS "vtkHybridCS;vtkParallelCS;KWCommon;vtksys;/usr/local/lib/libhdf5.so;vtkClientServer;")
SET(vtkPVServerCommonCS_LIB_DEPENDS "vtkClientServer;vtkPVServerCommon;vtkParallelCS;vtkHybridCS;vtkRenderingCS;")
SET(vtkPVServerCommonTCL_LIB_DEPENDS "vtkPVServerCommon;vtkCommonTCL;")
SET(vtkPVFilters_LIB_DEPENDS "vtkPVServerCommon;vtkPVServerCommonCS;vtkXdmfCS;vtkHybridCS;vtkParallelCS;vtkVolumeRenderingCS;vtkWidgetsCS;KWCommon;vtksys;/usr/local/lib/libhdf5.so;SPCTH;vtkClientServer;")
SET(vtkPVFiltersCS_LIB_DEPENDS "vtkClientServer;vtkPVFilters;vtkParallelCS;vtkHybridCS;vtkRenderingCS;vtkVolumeRenderingCS;")
SET(vtkPVServerManager_LIB_DEPENDS "vtkPVFiltersCS;vtkClientServer;KWCommon;")
SET(vtkPVServerManagerTCL_LIB_DEPENDS "vtkPVServerCommonTCL;vtkPVServerManager;vtkCommonTCL;")
SET(KWWidgets_LIB_DEPENDS "vtkCommonTCL;vtkRendering;vtkVolumeRendering;vtkHybrid;vtkWidgets;vtkParallel;png;vtksys;")
SET(vtkKWParaView_LIB_DEPENDS "KWCommon;KWWidgets;vtkPVServerManagerTCL;vtkPVServerCommonTCL;vtkPVFilters;vtkXdmfCS;")
SET(vtkKWParaViewCS_LIB_DEPENDS "vtkClientServer;vtkKWParaView;vtkPVFiltersCS;vtkPVServerCommonCS;")
SET(KWSimpleWindowWithImageWidgetExampleLib_LIB_DEPENDS "")
